package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.dto.FilesDTO;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.KnowledgeBasesDTO;
import com.pjilisense.flxai.service.KnowledgeBasesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * ${comments}
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2025-01-14
 */
@RestController
@RequestMapping(Constant.BASE_PATH+"knowledgebases")
@Api(tags="${comments}")
public class KnowledgeBasesController {

    private static Logger logger = LoggerFactory.getLogger(KnowledgeBasesController.class);

    @Autowired
    private KnowledgeBasesService knowledgeBasesService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    public Result<PageData<KnowledgeBasesDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<KnowledgeBasesDTO> page = knowledgeBasesService.page(params);

        return new Result<PageData<KnowledgeBasesDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<KnowledgeBasesDTO> get(@PathVariable("id") String id){
        KnowledgeBasesDTO data = knowledgeBasesService.get(id);

        return new Result<KnowledgeBasesDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody KnowledgeBasesDTO dto){
        knowledgeBasesService.save(dto);

        return new Result().ok(dto);
    }
    @PostMapping("/modifyDescriptuon")
    @ApiOperation("修改描述")
    public Result modifyDescriptuon(@RequestBody KnowledgeBasesDTO dto){
        boolean suc =knowledgeBasesService.modifyDescriptuon(dto);
        return new Result().ok(suc);
    }
    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody KnowledgeBasesDTO dto){

        knowledgeBasesService.update(dto);

        return new Result().ok(dto);
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody String[] ids){
        knowledgeBasesService.delete(ids);

        return new Result();
    }

}